@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""API models package."""
-from . import asset_mixin, devices, fields, labels, saved_query, users
+"""APIs for working with assets, saved queries, fields, and tags."""
 from .asset_mixin import AssetMixin
 from .devices import Devices
 from .fields import Fields
@@ -15,10 +14,4 @@ __all__ = (
     "SavedQuery",
     "Fields",
     "Labels",
-    "users",
-    "devices",
-    "fields",
-    "asset_mixin",
-    "labels",
-    "saved_query",
 )
