@@ -1,21 +1,19 @@
 # -*- coding: utf-8 -*-
 """APIs for working with system components."""
 from .activity_logs import ActivityLogs
-from .central_core import CentralCore
 from .dashboard import Dashboard
 from .instances import Instances
 from .meta import Meta
 from .remote_support import RemoteSupport
 from .settings_global import SettingsGlobal
 from .settings_gui import SettingsGui
+from .settings_identity_providers import SettingsIdentityProviders
 from .settings_lifecycle import SettingsLifecycle
 from .signup import Signup
-from .system import System
 from .system_roles import SystemRoles
 from .system_users import SystemUsers
 
 __all__ = (
-    "CentralCore",
     "Dashboard",
     "Instances",
     "Meta",
@@ -23,9 +21,9 @@ __all__ = (
     "SettingsGui",
     "SettingsLifecycle",
     "Signup",
-    "System",
     "SystemRoles",
     "SystemUsers",
     "RemoteSupport",
     "ActivityLogs",
+    "SettingsIdentityProviders",
 )
