@@ -79,7 +79,7 @@ class SettingsMixins(ModelMixins):
         )
         raise NotFoundError(tablize(value=valids, err=err))
 
-    def update_section(self, section: str, **kwargs) -> dict:
+    def update_section(self, section: str, check_unchanged: bool = True, **kwargs) -> dict:
         """Update the current settings for a section of system settings.
 
         Args:
@@ -107,12 +107,13 @@ class SettingsMixins(ModelMixins):
             new_config=new_config,
             source=source,
         )
-        config_unchanged(
-            schemas=schemas,
-            old_config=old_config,
-            new_config=new_config,
-            source=source,
-        )
+        if check_unchanged:
+            config_unchanged(
+                schemas=schemas,
+                old_config=old_config,
+                new_config=new_config,
+                source=source,
+            )
 
         full_config[section] = new_config
 
