@@ -3,12 +3,25 @@
 import click
 
 from ..context import AliasedGroup
-from . import (cmd_count, cmd_count_by_saved_query, cmd_destroy, cmd_get,
-               cmd_get_by_id, cmd_get_by_saved_query, cmd_get_fields,
-               cmd_get_fields_default, cmd_get_tags, grp_saved_query)
-from .grp_common import (GET_BY_VALUE_BUILDERS, GET_BY_VALUE_FIELD,
-                         GET_BY_VALUE_REGEX_BUILDERS, GET_BY_VALUES_BUILDERS,
-                         gen_get_by_cmd)
+from . import (
+    cmd_count,
+    cmd_count_by_saved_query,
+    cmd_destroy,
+    cmd_get,
+    cmd_get_by_id,
+    cmd_get_by_saved_query,
+    cmd_get_fields,
+    cmd_get_fields_default,
+    cmd_get_tags,
+    grp_saved_query,
+)
+from .grp_common import (
+    GET_BY_VALUE_BUILDERS,
+    GET_BY_VALUE_FIELD,
+    GET_BY_VALUE_REGEX_BUILDERS,
+    GET_BY_VALUES_BUILDERS,
+    gen_get_by_cmd,
+)
 
 
 @click.group(cls=AliasedGroup)
