@@ -24,7 +24,7 @@ OPTIONS = [
 @add_options(OPTIONS)
 @click.pass_context
 def cmd(ctx, url, key, secret, export_format, **kwargs):
-    """Get saved queries."""
+    """Get saved queries by tags."""
     client = ctx.obj.start_client(url=url, key=key, secret=secret)
 
     p_grp = ctx.parent.parent.command.name
