@@ -3,7 +3,7 @@
 import click
 
 from ...context import AliasedGroup
-from . import cmd_get
+from . import cmd_admin_script_upload, cmd_factory_reset, cmd_get
 
 
 @click.group(cls=AliasedGroup)
@@ -12,3 +12,5 @@ def instances():
 
 
 instances.add_command(cmd_get.cmd)
+instances.add_command(cmd_factory_reset.cmd)
+instances.add_command(cmd_admin_script_upload.cmd)
