@@ -15,5 +15,5 @@ def cmd(ctx, url, key, secret, name, **kwargs):
     client = ctx.obj.start_client(url=url, key=key, secret=secret)
 
     with ctx.obj.exc_wrap(wraperror=ctx.obj.wraperror):
-        client.system.roles.delete(name=name)
+        client.system_roles.delete(name=name)
         ctx.obj.echo_ok(f"Deleted role {name!r}")
