@@ -4,25 +4,11 @@ from ...context import CONTEXT_SETTINGS, click
 from ...options import AUTH, add_options
 from .grp_common import EXPORT, handle_export
 
-# ROLE_NAME = click.option(
-#     "--name",
-#     "-n",
-#     "name",
-#     help="Name of role to get",
-#     default=None,
-#     required=False,
-#     show_envvar=True,
-#     show_default=True,
-# )
-
 OPTIONS = [
     *AUTH,
     EXPORT,
-    # ROLE_NAME,
 ]
 
-f"{OPTIONS}"
-
 
 @click.command(name="get", context_settings=CONTEXT_SETTINGS)
 @add_options(OPTIONS)
