@@ -25,5 +25,5 @@ def cmd(ctx, url, key, secret, name, **kwargs):
     client = ctx.obj.start_client(url=url, key=key, secret=secret)
 
     with ctx.obj.exc_wrap(wraperror=ctx.obj.wraperror):
-        client.system.users.delete(name=name)
+        client.system_users.delete(name=name)
         ctx.obj.echo_ok(f"Deleted user {name!r}")
