@@ -43,9 +43,12 @@ def handle_export(ctx, data, export_format, **kwargs):
                 f"First Name: {first_name!r}",
                 f"Last Name: {last_name!r}",
                 f"Source: {source!r}",
-                f"Password Reset Link: {password_reset_link}",
-                f"Email Password Reset Link Error: {email_password_link_error}",
             ]
+            if password_reset_link:
+                lines += [
+                    f"Password Reset Link: {password_reset_link}",
+                    f"Email Password Reset Link Error: {email_password_link_error}",
+                ]
 
             click.secho(", ".join(lines))
         ctx.exit(0)
