@@ -24,23 +24,15 @@ from .api import (
     SystemRoles,
     SystemUsers,
     Users,
+    OpenAPISpec,
 )
 from .auth import ApiKey
 from .constants.api import TIMEOUT_CONNECT, TIMEOUT_RESPONSE
-from .constants.logs import (
-    LOG_FILE_MAX_FILES,
-    LOG_FILE_MAX_MB,
-    LOG_FILE_NAME,
-    LOG_FILE_PATH,
-    LOG_FMT_BRIEF,
-    LOG_FMT_VERBOSE,
-    LOG_LEVEL_API,
-    LOG_LEVEL_AUTH,
-    LOG_LEVEL_CONSOLE,
-    LOG_LEVEL_FILE,
-    LOG_LEVEL_HTTP,
-    LOG_LEVEL_PACKAGE,
-)
+from .constants.logs import (LOG_FILE_MAX_FILES, LOG_FILE_MAX_MB,
+                             LOG_FILE_NAME, LOG_FILE_PATH, LOG_FMT_BRIEF,
+                             LOG_FMT_VERBOSE, LOG_LEVEL_API, LOG_LEVEL_AUTH,
+                             LOG_LEVEL_CONSOLE, LOG_LEVEL_FILE, LOG_LEVEL_HTTP,
+                             LOG_LEVEL_PACKAGE)
 from .exceptions import ConnectError, InvalidCredentials
 from .http import Http
 from .logs import LOG, add_file, add_stderr, get_obj_log, set_log_level
@@ -469,6 +461,14 @@ class Connect:
         """Show object info."""
         return self.__str__()
 
+    @property
+    def openapi(self) -> OpenAPISpec:
+        """Work with the OpenAPI specification file."""
+        self.start()
+        if not hasattr(self, "_openapi"):
+            self._openapi = OpenAPISpec(**self.API_ARGS)
+        return self._openapi
+
     @classmethod
     def _get_exc_reason(cls, exc: Exception) -> str:
         """Trim exceptions down to a more user friendly display.
