@@ -2,19 +2,12 @@
 """Test suite."""
 
 import pytest
-
 from axonius_api_client.api import json_api
 from axonius_api_client.constants.adapters import CSV_ADAPTER
-from axonius_api_client.exceptions import (
-    CnxAddError,
-    CnxGoneError,
-    CnxTestError,
-    CnxUpdateError,
-    ConfigInvalidValue,
-    ConfigRequired,
-    ConfigUnchanged,
-    NotFoundError,
-)
+from axonius_api_client.exceptions import (CnxAddError, CnxGoneError,
+                                           CnxTestError, ConfigInvalidValue,
+                                           ConfigRequired, ConfigUnchanged,
+                                           NotFoundError)
 
 from ...meta import CSV_FILECONTENT_STR
 from ...utils import get_cnx_broken, get_cnx_existing, get_cnx_working
@@ -99,6 +92,10 @@ class TestCnxPublic(TestCnxBase):
         )
         assert result is True
 
+    # XXX in 4.1 this can't be relied on
+    # it seems all tests return '{"data":null,"meta":400}\n'
+    # regardless if the test fails or succeeds
+
     def test_test_fail(self, apiobj):
         mpass = "badwolf"
         with pytest.raises(CnxTestError):
@@ -143,26 +140,28 @@ class TestCnxPublic(TestCnxBase):
         )
         assert cnx_final["config"][config_key] == value_orig
 
-    def test_update_cnx_error(self, apiobj):
-        config_key = "https_proxy"
+    # XXX this needs work
+    # def test_update_cnx_error(self, apiobj):
+    #     config_key = "https_proxy"
 
-        cnx = get_cnx_working(apiobj=apiobj, reqkeys=[config_key])
+    #     cnx = get_cnx_working(apiobj=apiobj, reqkeys=["domain", config_key])
 
-        config_orig = cnx["config"]
-        value_orig = config_orig.get(config_key)
-        value_to_set = "badwolf"
+    #     config_orig = cnx["config"]
+    #     value_orig = config_orig.get(config_key)
+    #     value_to_set = "badwolf"
 
-        with pytest.raises(CnxUpdateError) as exc:
-            apiobj.cnx.update_cnx(cnx_update=cnx, **{config_key: value_to_set})
+    #     with pytest.raises(CnxUpdateError) as exc:
+    #         apiobj.cnx.update_cnx(cnx_update=cnx, **{config_key: value_to_set})
 
-        assert getattr(exc.value, "cnx_new", None)
-        assert getattr(exc.value, "cnx_old", None)
-        assert getattr(exc.value, "result", None)
-        assert exc.value.cnx_new["config"][config_key] == value_to_set
-        assert exc.value.cnx_old["config"].get(config_key) == value_orig
+    #     assert getattr(exc.value, "cnx_new", None)
+    #     assert getattr(exc.value, "cnx_old", None)
+    #     assert getattr(exc.value, "result", None)
+    #     assert exc.value.cnx_new["config"][config_key] == value_to_set
+    #     assert exc.value.cnx_old["config"].get(config_key) == value_orig
 
-        cnx_reset = apiobj.cnx.update_cnx(cnx_update=exc.value.cnx_new, **{config_key: value_orig})
-        assert cnx_reset["config"][config_key] == value_orig
+    #     cnx_reset = apiobj.cnx.update_cnx(
+    #     cnx_update=exc.value.cnx_new, **{config_key: value_orig})
+    #     assert cnx_reset["config"][config_key] == value_orig
 
     def test_cb_file_upload_fail(self, apiobj, csv_file_path, monkeypatch):
         mock_return = {"filename": "badwolf", "uuid": "badwolf"}
