@@ -8,6 +8,8 @@ from axonius_api_client.constants.wizards import Entry, Flags, Results, Types
 from axonius_api_client.exceptions import NotFoundError, WizardError
 from axonius_api_client.parsers.wizards import WizardParser
 
+from ...utils import get_schema
+
 
 class TestWizard:
     @pytest.fixture(params=["api_devices", "api_users"])
@@ -26,6 +28,7 @@ class TestData:
         simple = wizard.APIOBJ.FIELD_SIMPLE
         cplex = wizard.APIOBJ.FIELD_COMPLEX
         sub = wizard.APIOBJ.FIELD_COMPLEX_SUB
+        get_schema(apiobj=wizard.APIOBJ, field=cplex)
 
         entries = [
             {Entry.TYPE: Types.SIMPLE, Entry.VALUE: f"{simple} exists"},
@@ -222,6 +225,7 @@ class TestGetFieldComplex(TestWizard):
 
     def test_valid(self, wizard):
         field = wizard.APIOBJ.FIELD_COMPLEX
+        get_schema(apiobj=wizard.APIOBJ, field=field)
         ret = wizard._get_field_complex(value=field, value_raw=f"{field} blah blah")
         assert ret["name_qual"] == field
 
@@ -698,6 +702,7 @@ class TestParseSimple(TestWizard):
 class TestParseComplex(TestWizard):
     def test_valid(self, wizard):
         field = wizard.APIOBJ.FIELD_COMPLEX
+        get_schema(apiobj=wizard.APIOBJ, field=field)
         sub = wizard.APIOBJ.FIELD_COMPLEX_SUB
         entry = {
             Entry.TYPE: "complex",
@@ -747,6 +752,8 @@ class TestParseComplex(TestWizard):
 
     def test_invalid(self, wizard):
         field = wizard.APIOBJ.FIELD_COMPLEX
+        get_schema(apiobj=wizard.APIOBJ, field=field)
+
         sub = wizard.APIOBJ.FIELD_COMPLEX_SUB
         entry = {
             Entry.TYPE: "complex",
